﻿using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Data;
using System.Linq;
using System.ServiceModel.Web;
using System.Web;
using System.Web.Script.Services;
using System.Web.Services;
using Infragistics.Web.Mvc;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;

/// <summary>
/// Summary description for WebService
/// </summary>
[WebService(Namespace = "http://tempuri.org/")]
[WebServiceBinding(ConformsTo = WsiProfiles.BasicProfile1_1)]
// To allow this Web Service to be called from script, using ASP.NET AJAX, uncomment the following line. 
[System.Web.Script.Services.ScriptService]
public class WebService : System.Web.Services.WebService
{
    public WebService()
    {

    }

    [WebMethod]
    public string HelloWorld()
    {
        return "Hello World";
    }

    [System.Web.Script.Services.ScriptMethod(UseHttpGet = true)]
    [WebMethod]
    public ResponseObject FetchData()
    {
        string query = this.Context.Request.QueryString.ToString();
        NameValueCollection queryString = HttpUtility.ParseQueryString(this.Context.Request.QueryString.ToString());

        int currentPage = Convert.ToInt32(this.Context.Request.QueryString["page"]);
        int pageSize = Convert.ToInt32(this.Context.Request.QueryString["pageSize"]);

        List<SortExpression> sortExpressions = BuildSortExpressions(queryString, "sort");

        IEnumerable<Customer> gridData = GetCustomers();

        ResponseObject resp = new ResponseObject();

        if (sortExpressions.Count != 0)
        {
            if (sortExpressions[0].Mode == SortMode.Ascending)
            {
                gridData = gridData.OrderBy(x => x.Name);
            }
            else
            {
                gridData = gridData.OrderByDescending(x => x.Name);
            }
        }

        resp.TotalRecordsCount = gridData.Count();

        if (pageSize != 0)
        {
            resp.Data = gridData.Skip(currentPage * pageSize).Take(pageSize);
        }
        else
        {
            resp.Data = gridData;
        }

        
        return resp;
    }

    private List<Customer> GetCustomers()
    {
        List<Customer> list = new List<Customer>();

        list.Add(new Customer { ID = 1, Name = "John Smith", IsActive = true });
        list.Add(new Customer { ID = 2, Name = "Haralampi", IsActive = true });
        list.Add(new Customer { ID = 3, Name = "Haralampi", IsActive = true });
        list.Add(new Customer { ID = 4, Name = "John Smith", IsActive = true });
        list.Add(new Customer { ID = 5, Name = "John Smith", IsActive = true });
        list.Add(new Customer { ID = 6, Name = "John Smith", IsActive = true });
        list.Add(new Customer { ID = 7, Name = "John Smith", IsActive = true });
        list.Add(new Customer { ID = 8, Name = "John Smith", IsActive = true });
        list.Add(new Customer { ID = 9, Name = "Haralampi", IsActive = true });
        list.Add(new Customer { ID = 10, Name = "John Smith", IsActive = true });
        list.Add(new Customer { ID = 11, Name = "Haralampi", IsActive = false });
        list.Add(new Customer { ID = 12, Name = "Haralampi", IsActive = false });
        list.Add(new Customer { ID = 13, Name = "Haralampi", IsActive = false });


        return list;
    }

    public List<SortExpression> BuildSortExpressions(NameValueCollection queryString, string sortKey)
    {
        List<SortExpression> expressions = new List<SortExpression>();
        List<string> sortKeys = new List<string>();
        foreach (string key in queryString.Keys)
        {
            if (!string.IsNullOrEmpty(key) && key.StartsWith(sortKey))
            {
                SortExpression e = new SortExpression();
                e.Key = key.Substring(key.IndexOf("(")).Replace("(", "").Replace(")", "");
                e.Logic = "AND";
                e.Mode = queryString[key].ToLower().StartsWith("asc") ? SortMode.Ascending : SortMode.Descending;
                expressions.Add(e);
                sortKeys.Add(key);
            }
        }

        return expressions;
    }
}
